@@ -1,4 +1,4 @@
-import js_lib
+from . import js_lib
 
 create_doc = js_lib.var['prosemirror']['create_doc'].to_py()
 transform_doc = js_lib.var['prosemirror']['transform_doc'].to_py()
